package com.webstersmalley.iplayer.feed;

/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */

import java.util.HashSet;
import java.util.Set;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.apache.log4j.Logger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;

public class FeedDownloader {
	private Logger logger = Logger.getLogger(getClass());
	private final static String URL_STUB = "http://feeds.bbc.co.uk/iplayer/";
	private final static String URL_TAIL = "/list/limit/400";
	
	private String url;
	private Set<Program> programs;
	
	public FeedDownloader() {
		
	}
	
	public void setFeedname(String feedname) {
		this.url = URL_STUB + feedname + URL_TAIL; 
	}
	
	private void download() throws Exception {
		programs = new HashSet<Program>();
		ProgramXMLFactory programFactory = new ProgramXMLFactory();
		DocumentBuilder builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
		Document doc = builder.parse(url);

		NodeList nodes = doc.getElementsByTagName("entry");
		
		for (int i = 0; i < nodes.getLength(); i++) {
			Element element = (Element)nodes.item(i);
			programs.add(programFactory.getProgramFromElement(element));
		}
	}
	
	public synchronized Set<Program> getPrograms() {
		if (programs == null) {
			try {
				download();
			} catch (Exception e) {
				logger.error("Error loading feed", e);
				throw new RuntimeException("Error loading feed", e);
			}
		}
		return programs;
	}
}
