package com.webstersmalley.iplayer.feed;

/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */


import java.util.Random;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathFactory;

import org.apache.http.client.HttpClient;
import org.apache.http.client.ResponseHandler;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.BasicResponseHandler;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.log4j.Logger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class IPhoneProgramDownloader implements ProgramDownloader {
	private final Random random = new Random();
	private final XPath xpath = XPathFactory.newInstance().newXPath();
	private Logger logger = Logger.getLogger(getClass());
	
	private String decodeProgramGroupId(String programId) {
		String[] fields = programId.split(":");
		return fields[fields.length-1];
	}
	
	private String getRandomDigits(int length) {
		long mask = (new Double(Math.pow(10, length)).longValue() - 1);
		return new Long(random.nextLong()%mask).toString();
		
	}
	
	public void downloadProgram(Program program) {
		String programGroup = decodeProgramGroupId(program.getId());
		String playlistUrl = "http://www.bbc.co.uk/iplayer/playlist/" + programGroup;
		logger.debug("Got playlist Url: " + playlistUrl);
		
		try {
			DocumentBuilder builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
			Document doc = builder.parse(playlistUrl);

			XPathExpression expr = xpath.compile("//item");
			Element node = (Element)expr.evaluate(doc, XPathConstants.NODE);
			String programIdentifier = node.getAttribute("identifier");
			
			logger.debug("Got prog id: " + programIdentifier);
			
			String authUrl = "http://www.bbc.co.uk/mediaselector/3/auth/iplayer_streaming_http_mp3/" + programIdentifier + "?r=" + getRandomDigits(12);
			
			logger.debug("Auth URL is: " + authUrl);
			
			HttpClient client = new DefaultHttpClient();
			client.getParams().setParameter("http.useragent", "Apple iPhone v1.1.1 CoreMedia v1.0.0.3A110a");
			
			HttpGet get = new HttpGet(authUrl);
			
			ResponseHandler<String> handler = new BasicResponseHandler();
			
			
			String body = client.execute(get, handler);
		
			logger.info("Got: " + body);
			
		} catch (Exception e) {
			throw new RuntimeException("Error downloading program", e);
		}
	}

}
