/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package com.webstersmalley.iplayer.informer;

import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathFactory;

import org.apache.log4j.Logger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * @author Matthew Smalley
 *
 */
public class ProgramInformation {
	private Logger logger = Logger.getLogger(getClass());
	private Document programDocument;
	private Document programSetDocument;
	private final XPath xpath = XPathFactory.newInstance().newXPath();
	private String programName;
	private String programSetName;
	private String author;
	
	public String getAuthor() {
		return author;
	}
	
	public Document getProgramDocument() {
		return programDocument;
	}
	public void setProgramDocument(Document programDocument) {
		this.programDocument = programDocument;
		this.programName = getTitle(programDocument);
	}
	public Document getProgramSetDocument() {
		return programSetDocument;
	}
	public void setProgramSetDocument(Document programSetDocument) {
		this.programSetDocument = programSetDocument;
		this.programSetName = getTitle(programSetDocument);
		this.author = getAuthor(programSetDocument);
	}
	
	private String getAuthor(Document d) {
		try {
			XPathExpression expr = xpath.compile("//author/name");
			Element e = (Element)expr.evaluate(d, XPathConstants.NODE);
			return e.getTextContent();
		} catch (Exception e) {
			logger.error("Error reading author element", e);
			throw new RuntimeException("Error reading author element", e);
		}
	}

	private String getTitle(Document d) {
		try {
			XPathExpression expr = xpath.compile("//entry/title");
			Element e = (Element)expr.evaluate(d, XPathConstants.NODE);
			return e.getTextContent();
		} catch (Exception e) {
			logger.error("Error reading title element", e);
			throw new RuntimeException("Error reading title element", e);
		}
	}
	
	public String getProgramSetName() {
		return programSetName;
	}
	
	public String getProgramName() {
		return programName;
	}
	
	@Override
	public String toString() {
		return programSetName + ": " + programName;
	}
}
