/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package com.webstersmalley.iplayer.informer;

import java.util.HashMap;
import java.util.Map;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathFactory;

import org.apache.log4j.Logger;
import org.w3c.dom.Document;
import org.w3c.dom.Element;


/**
 * @author Matthew Smalley
 * 
 */

public class ProgramInformer {
	private final XPath xpath = XPathFactory.newInstance().newXPath();
	private final DocumentBuilder builder;
	private Logger logger = Logger.getLogger(getClass());
	private final static String EPISODE_URL_STUB = "http://feeds.bbc.co.uk/iplayer/episode/";
	private Map<String, Document> downloadCache = new HashMap<String, Document>();
	
	private Document download(String url) {
		try {
			if (!downloadCache.containsKey(url)) {
				Document d = builder.parse(url);
				downloadCache.put(url, d);
			}
			return downloadCache.get(url);
		} catch (Exception e) {
			logger.error("Error downloading: " + url, e);
			throw new RuntimeException("Error downloading: " + url, e);
		}
	}

	public ProgramInformer() {
		try {
			builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
		} catch (Exception e) {
			logger.error("Error instantiating document builder", e);
			throw new RuntimeException("Error instantiating document builder", e);
		}
	}

	public Document getEpisodeInfo(String programKey) {
		try {
			String url = EPISODE_URL_STUB + programKey;
			logger.info("Downloading program xml from: " + url);
			return download(url);

		} catch (Exception e) {
			logger.error("Error getting program information", e);
			throw new RuntimeException("Error getting program information", e);
		}

	}

	public Document getProgramSetInfo(Document programDocument) {
		try {
			XPathExpression expr = xpath.compile("//link[@rel='parent']");
			Element node = (Element) expr.evaluate(programDocument, XPathConstants.NODE);
			String programSetUrl = node.getAttribute("href");
			
			logger.info("Downloading program set xml from: " + programSetUrl);
			
			return download(programSetUrl);

		} catch (Exception e) {
			logger.error("Error getting program set information", e);
			throw new RuntimeException("Error getting program set information", e);
		}

	}

	public Document getProgramSetInfo(String programKey) {
		Document program = getEpisodeInfo(programKey);
		return getProgramSetInfo(program);
	}
	
	public ProgramInformation getProgramInformation(String programKey) {
		ProgramInformation progInf = new ProgramInformation();
		progInf.setProgramDocument(getEpisodeInfo(programKey));
		progInf.setProgramSetDocument(getProgramSetInfo(progInf.getProgramDocument()));
		return progInf;
	}
}
