/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package com.webstersmalley.iplayer.mp3;

import java.io.File;
import java.io.OutputStream;

import javax.xml.transform.OutputKeys;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

import org.apache.log4j.Logger;
import org.w3c.dom.Document;

/**
 * @author Matthew Smalley
 *
 */
public class FileSystemUtils {
	private Logger logger = Logger.getLogger(getClass());
	public void checkFolder(String folderName) {
		logger.info("Setting up folder: " + folderName);
		File f = new File(folderName);
		if (!f.exists()) {
			if (!f.mkdirs()) {
				throw new RuntimeException("Error creating folder: " + folderName);
			}
		}
		if (!f.isDirectory()) {
			throw new RuntimeException("Specified folder exists but is not a folder, or cannot be read");
		}
	}
	

	public void removeFile(File f) {
		logger.info("Removing: " + f.getName());
		if (f.isDirectory()) {
			File[] contents = f.listFiles();
			for (File child : contents) {
				removeFile(child);
			}
		}
		if (!f.delete()) {
			//throw new RuntimeException("Error deleting folder: " + f.getName());
		}
	}

	public boolean destinationFileNewer(String input, String output) {
		File inputFile = new File(input);
		File outputFile = new File(output);
		if (outputFile.exists()) {
			return outputFile.lastModified() >= inputFile.lastModified();
		} else { 
			return false;
		}
	}
	
	public void writeXML(OutputStream os, Document doc) throws TransformerException {
		DOMSource domSource = new DOMSource(doc);
		StreamResult streamResult = new StreamResult(os);
		TransformerFactory tf = TransformerFactory.newInstance();
		Transformer serializer = tf.newTransformer();
		serializer.setOutputProperty(OutputKeys.ENCODING,"ISO-8859-1");
		serializer.setOutputProperty(OutputKeys.INDENT,"yes");
		serializer.transform(domSource, streamResult); 
	}
}
