/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package com.webstersmalley.iplayer.organiser;

import java.io.File;
import java.io.FileOutputStream;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import java.io.FileFilter;

import org.apache.log4j.Logger;

import com.webstersmalley.iplayer.informer.ProgramInformation;
import com.webstersmalley.iplayer.informer.ProgramInformer;
import com.webstersmalley.iplayer.mp3.FileSystemUtils;
import com.webstersmalley.iplayer.mp3.MP3Utils;

/**
 * @author Matthew Smalley
 * 
 */
public class PostDownloadProcessor {
	private Logger logger = Logger.getLogger(getClass());
	private String inputFolder;
	private String outputFolder;
	private MP3Utils mp3Utils;
	private String preset;
	private RadioProgramBeanFactory radioProgramBeanFactory;

	public void setPreset(String preset) {
		this.preset = preset;
	}
	
	public void setMp3Utils(MP3Utils mp3Utils) {
		this.mp3Utils = mp3Utils;
	}

	public void setInputFolder(String inputFolder) {
		this.inputFolder = inputFolder;
	}

	public void setOutputFolder(String outputFolder) {
		if (!outputFolder.endsWith(File.separator)) {
			outputFolder += File.separator;
		}
		this.outputFolder = outputFolder;
	}
	
	public void setRadioProgramBeanFactory(RadioProgramBeanFactory radioProgramBeanFactory) {
		this.radioProgramBeanFactory = radioProgramBeanFactory;
	}

	/**
	 * For each mp3 in input folder, performs the following process:
	 * <ul>
	 * <li>Use filename to get program name and program set name</li>
	 * <li>Re-encode</li>
	 * <li>Retag / move into destination folder</li>
	 * </ul>
	 */
	public void go() {
		File inputFolderFile = new File(inputFolder);
		File[] children = inputFolderFile.listFiles(new MP3FileFilter());
		for (File mp3file : children) {
			try {
				RadioProgramBean program = radioProgramBeanFactory.getBeanFromFile(mp3file.getName());

				String newFilename = outputFolder + program.getFolder() + File.separator + program.getFilename();
				
				// Re-encode & re-tag
				logger.info("Re-encoding: " + mp3file.getName() + " as " + newFilename);
				mp3Utils.reencodeMP3(mp3file.getAbsolutePath(), newFilename, preset, false);
				
				logger.info("Writing tags for: " + newFilename);
				mp3Utils.retagMP3(newFilename, program);
			} catch (Exception e) {
				logger.error("Error processing file: " + mp3file.getName(), e);
				throw new RuntimeException ("Error processing file: " + mp3file.getName(), e);
			}
		}
	}

	private final class MP3FileFilter implements FileFilter {

		@Override
		public boolean accept(File arg0) {
			return (arg0.getName().toLowerCase().endsWith(".mp3"));
		}

	}
}
