package com.webstersmalley.iplayer.organiser;

/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */



public class RadioProgramBeanFactory {
    private String defaultGenre;
    private String defaultArtist;

    /**
     * Splits a filename that looks like this: "2025_-_Episode_2_b00j0hbm_default.partial.mp3" into its constituent parts.
     * Need to also consider sometimes the filename looks like this: "A_Stone_Woman_-_Episode_3_b007jtx6.mp3"
     * @param filename
     * @return
     */
    
    public RadioProgramBean getBeanFromFile(String filename) {
        RadioProgramBean bean = new RadioProgramBean();

        filename = filename.replaceAll("_default.partial", "");
        
        String[] pieces = filename.split("_");
        
        int i = 0;
        StringBuffer sb = new StringBuffer();
        while (i < pieces.length-1 && !pieces[i].equals("-") && !pieces[i].equals(".mp3")) {
            sb.append(pieces[i]);
            sb.append(" ");
            i++;
        }
        bean.setSeriesTitle(sb.toString().trim());
        
        i++;
        sb = new StringBuffer();
        while (i < pieces.length-1 && !pieces[i].equals("-") && !pieces[i].equals(".mp3")) {
            sb.append(pieces[i]);
            sb.append(" ");
            i++;
        }
        bean.setEpisodeTitle(bean.getSeriesTitle() + " - " + sb.toString().trim());
        
        if (defaultGenre != null) {
            bean.setGenre(defaultGenre);
        }
        if (defaultArtist != null) {
            bean.setArtist(defaultArtist);
        }
        
        return bean;
    }

    public String getDefaultGenre() {
        return defaultGenre;
    }

    public void setDefaultGenre(String defaultGenre) {
        this.defaultGenre = defaultGenre;
    }

    public String getDefaultArtist() {
        return defaultArtist;
    }

    public void setDefaultArtist(String defaultArtist) {
        this.defaultArtist = defaultArtist;
    }
    
    
}
