package com.webstersmalley.iplayer.mp3;

/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */

import java.io.File;

import junit.framework.TestCase;

import org.apache.log4j.Logger;
import org.blinkenlights.jid3.ID3Exception;
import org.blinkenlights.jid3.ID3Tag;
import org.blinkenlights.jid3.MP3File;
import org.blinkenlights.jid3.MediaFile;
import org.blinkenlights.jid3.v1.ID3V1_0Tag;
import org.blinkenlights.jid3.v2.ID3V2_3_0Tag;
import org.junit.After;
import org.junit.Before;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import com.webstersmalley.iplayer.organiser.Retagger;
import com.webstersmalley.iplayer.organiser.RetaggerSetup;

public class ID3Test extends TestCase {

	public void testID3Reader() throws ID3Exception {
		String filename = "src/test/resources/testinput.mp3";
		MediaFile mediaFile = new MP3File(new File(filename));

		ID3Tag[] tags = mediaFile.getTags();
		for (ID3Tag tag : tags) {
			System.out.println("Looking at tag: " + tag);
			if (tag instanceof ID3V1_0Tag) {
				System.out.println("V1.0 tag found");
				ID3V1_0Tag tagv10 = (ID3V1_0Tag) tag;
				if (tagv10.getTitle() != null) {
					System.out.println(tagv10.getTitle());
				}
			} else if (tag instanceof ID3V2_3_0Tag) {
				System.out.println("V2.3 tag found");
				ID3V2_3_0Tag tagv23 = (ID3V2_3_0Tag) tag;
				if (tagv23.getTIT2TextInformationFrame() != null) {
					System.out.println("Title = " + tagv23.getTIT2TextInformationFrame().getTitle());
				}
				try {
					System.out.println("Year = " + tagv23.getYear()); // reads
					// TYER
					// frame
				} catch (ID3Exception e) {
					System.out.println("Couldn't get read year from tag: " + e.toString());
				}

			}
		}
	}
}
