/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package com.webstersmalley.iplayer.mp3;

import static org.junit.Assert.assertEquals;
import org.blinkenlights.jid3.v2.ID3V2Tag;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import com.webstersmalley.iplayer.organiser.RetaggerSetup;

/**
 * @author Matthew Smalley
 * 
 */
public class testMP3Utils {
	private RetaggerSetup setup;
	private MP3Utils mp3Utils;

	@Before
	public void setupFiles() {
		ApplicationContext ac = new ClassPathXmlApplicationContext(
				"beans-test.xml");
		setup = (RetaggerSetup) ac.getBean("retaggerSetup");
		mp3Utils = (MP3Utils) ac.getBean("mp3Utils");
		setup.setup();
	}

	@After
	public void tearDownFiles() {
		setup.tearDown();
	}

	@Test
	public void testReencodeFolder() {
		String inputFolder = "testfolder/input";
		String outputFolder = "testfolder/output/sorted";
		String preset = "64";
		mp3Utils.reencodeFolder(inputFolder, outputFolder, preset);
		System.out.println("hoo");
	}
	
	@Test
	public void testReencodeMP3() {
		String inputFilename = "testfolder/input/2025_-_Episode_2_b00j0hbm_default.partial.mp3";
		String outputFilename = "testfolder/output/testoutput.mp3";
		String preset = "64";

		mp3Utils.reencodeMP3(inputFilename, outputFilename, preset);

		ID3V2Tag inputTags = mp3Utils.getID3V2Tags(inputFilename);
		ID3V2Tag outputTags = mp3Utils.getID3V2Tags(outputFilename);
		compareTags(inputTags, outputTags);
	}
	
	private void compareTags(ID3V2Tag a, ID3V2Tag b) {
		try {
			assertEquals(a.getAlbum(), b.getAlbum());
			assertEquals(a.getArtist(), b.getArtist());
			assertEquals(a.getComment(), b.getComment());
			assertEquals(a.getCRC(), b.getCRC());
			assertEquals(a.getExtendedHeader(), b.getExtendedHeader());
			assertEquals(a.getGenre(), b.getGenre());
			assertEquals(a.getPaddingLength(), b.getPaddingLength());
			assertEquals(a.getTitle(), b.getTitle());
			assertEquals(a.getTrackNumber(), b.getTrackNumber());
			assertEquals(a.getUnsynchronization(), b.getUnsynchronization());
		} catch (Exception e) {
			throw new RuntimeException("Error comparing id3 tags...", e);
		}
	}
}
