package com.webstersmalley.iplayer.organiser;
/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */

import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import org.apache.log4j.Logger;

import com.webstersmalley.iplayer.mp3.FileSystemUtils;

public class RetaggerSetup {
	Logger logger = Logger.getLogger(getClass());
	private String inputFolder;
	private String outputFolder;
	private String sampleFileClasspath;
	private FileSystemUtils fileSystemUtils = new FileSystemUtils();

	public void setSampleFileClasspath(String sampleFileClasspath) {
		this.sampleFileClasspath = sampleFileClasspath;
	}

	public void setInputFolder(String inputFolder) {
		this.inputFolder = inputFolder;
	}

	public void setOutputFolder(String outputFolder) {
		this.outputFolder = outputFolder;
	}

	public String getOutputFolder() {
		return outputFolder;
	}
	
	private void copySampleFile(String newFilename) {
		try {
			logger.info("Copying classpath resource " + sampleFileClasspath + " to file " + newFilename);
			BufferedInputStream bis = new BufferedInputStream(this.getClass()
					.getResourceAsStream(sampleFileClasspath));
			BufferedOutputStream bos = new BufferedOutputStream(
					new FileOutputStream(newFilename));
			byte[] buffer = new byte[1024];
			int len;
			while ((len = bis.read(buffer)) > 0) {
				bos.write(buffer, 0, len);
			}
			bis.close();
			bos.flush();
			bos.close();
		} catch (IOException e) {
			throw new RuntimeException("Error copying file: "
					+ sampleFileClasspath + " to " + newFilename, e);
		}
	}

	public void setup() {
		fileSystemUtils.checkFolder(inputFolder);
		fileSystemUtils.checkFolder(inputFolder + File.separator + "folder2");
		fileSystemUtils.checkFolder(outputFolder);

		copySampleFile(inputFolder + File.separator + "2025_-_Episode_2_b00j0hbm_default.partial.mp3");
		copySampleFile(inputFolder + File.separator + "folder2" + File.separator + "2025_-_Episode_2_b00j0hbm_default.partial.mp3");
		copySampleFile(inputFolder + File.separator + "The_Brightonomicon_-_The_Lark_of_the_Lansdowne_Lioness_b00djm57_default.partial.mp3");
	}

	public void tearDown() {
		fileSystemUtils.removeFile(new File(inputFolder));
		fileSystemUtils.removeFile(new File(outputFolder));
		fileSystemUtils.removeFile(new File(outputFolder));
	}
}
