/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package com.webstersmalley.iplayer.organiser;

import static org.junit.Assert.assertEquals;

import java.io.File;

import org.blinkenlights.jid3.v2.ID3V2Tag;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import com.webstersmalley.iplayer.mp3.MP3Utils;

/**
 * @author Matthew Smalley
 *
 */
public class TestPostDownloadProcessor {
	private PostDownloadProcessor pdp;
	private RetaggerSetup setup;
	private MP3Utils mp3Utils;

	@Before
	public void setupFiles() {
		try {
			ApplicationContext ac = new ClassPathXmlApplicationContext("beans-test.xml");
			pdp = (PostDownloadProcessor)ac.getBean("pdp");
			mp3Utils = (MP3Utils)ac.getBean("mp3Utils");
			setup = (RetaggerSetup) ac.getBean("retaggerSetup");
			setup.setup();
		} catch (Exception e) {
			e.printStackTrace();
			throw new RuntimeException("Error", e);
		}
	}

	@After
	public void tearDownFiles() {
		setup.tearDown();
	}
	
	private void checkMP3File(String filename, String artist, String album, String song) {
		Assert.assertTrue(new File(filename).exists());
		ID3V2Tag tag = mp3Utils.getID3V2Tags(filename);
		assertEquals(album, tag.getAlbum());
		assertEquals(artist, tag.getArtist());
		assertEquals(song, tag.getTitle());
	}
	
	@Test
	public void testPostDownloadProcessor() {
		pdp.go();
		checkMP3File(setup.getOutputFolder() + File.separator + "BBC Radio" + File.separator + "2025" + File.separator + "2025 - Episode 2.mp3", "BBC Radio", "2025", "2025 - Episode 2");
		System.out.println("done");
	}
}
