package com.webstersmalley.iplayer.organiser;
/**
 *    Copyright 2009 Webster Smalley
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */

import java.io.File;

import org.blinkenlights.jid3.v2.ID3V2Tag;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import static org.junit.Assert.assertEquals;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import com.webstersmalley.iplayer.mp3.MP3Utils;

public class TestRetagger {
	private RetaggerSetup setup;
	private Retagger retagger;
	private MP3Utils mp3Utils;

	@Before
	public void setupFiles() {
		ApplicationContext ac = new ClassPathXmlApplicationContext(
				"beans-test.xml");
		setup = (RetaggerSetup) ac.getBean("retaggerSetup");
		retagger = (Retagger) ac.getBean("retagger");
		mp3Utils = (MP3Utils) ac.getBean("mp3Utils");
		setup.setup();
	}

	@After
	public void tearDownFiles() {
		setup.tearDown();
	}

	private void checkFileExists(String filename) {
		File f = new File(filename);
		if (!f.exists() || !f.isFile()) {
			throw new RuntimeException("File not found: " + filename);
		}
	}

	private void checkFile(String album, String song) {
		String filename = retagger.getOutputFolder() + File.separator + retagger.getBeanFactory().getDefaultArtist() + File.separator + album + File.separator + album + " - " + song + ".mp3";
		checkFileExists(filename);
		
		ID3V2Tag tag = mp3Utils.getID3V2Tags(filename);
		assertEquals(album, tag.getAlbum());
		assertEquals(retagger.getBeanFactory().getDefaultArtist(), tag.getArtist());
		assertEquals(album + " - " + song, tag.getTitle());
	}

	@Test
	public void testProcessFiles() {
		retagger.go();

		checkFile("2025", "Episode 2");
		checkFile("The Brightonomicon", "The Lark of the Lansdowne Lioness");

	}
}
